# PWCNet

## Original code

[https://github.com/NVlabs/PWC-Net](https://github.com/NVlabs/PWC-Net)

## Code license

See [LICENSE](LICENSE).

## Pretrained weights license

See [LICENSE](LICENSE).

## Citation

```
@InProceedings{Sun2018PWC-Net,
  author    = {Deqing Sun and Xiaodong Yang and Ming-Yu Liu and Jan Kautz},
  title     = {{PWC-Net}: {CNNs} for Optical Flow Using Pyramid, Warping, and Cost Volume},
  booktitle = CVPR,
  year      = {2018},
}
```